@@ -54,7 +54,7 @@ class URI(object):
                     self.port = '443'
         else:
             self.host += environ['SERVER_NAME']
-            self.port += environ['SERVER_POST']
+            self.port += environ['SERVER_PORT']
         self.script = environ.get('SCRIPT_NAME', '')
         self.path = environ.get('PATH_INFO', '')
         self.query = environ.get('QUERY_STRING', '')
@@ -243,7 +243,7 @@ class Request(object):
         self.cookie = Cookie.SimpleCookie()
         self.cookie.load(self.environ.get('HTTP_COOKIE', ''))
 
-    def redirect(self, location, permanent=True):
+    def redirect(self, location, permanent=False):
         """Set the location header and status."""
         self.res.headers['Location'] = location
         if permanent is True:
@@ -272,14 +272,10 @@ class Yaro(object):
         """Take the thing to wrap."""
         self.app = app
         self.extra_props = extra_props
-        
+
     def __call__(self, environ, start_response):
         """Create Request, call thing, unwrap results and respond."""
-        if 'yaro.request' in environ:
-            req = environ['yaro.request']
-        else:
-            req = Request(environ, start_response, self.extra_props)
-            environ['yaro.request'] = req 
+        req = Request(environ, start_response, self.extra_props)
         body = self.app(req)
         if body is None:
             body = req.res.body
